numpy.ndindex
=============

.. currentmodule:: numpy

.. autoclass:: ndindex

   

   .. HACK
      .. autosummary::
         :toctree:
      
         ndindex.__init__
         ndindex.ndincr
         ndindex.next



   

